import React, { PropsWithChildren } from 'react';
import { OptionProps } from './components/Option';
import { SelectOption, SelectOptionType } from '../types';
export declare type ListBoxProps<T> = PropsWithChildren<{
    /**
     * ⚠️ _Consult a designer before using this prop, in most cases it shouldn't be used._
     * Determines whether or not a search input should be rendered in the select list. If set to true, the search input will only render if there are more than 7 options.
     */
    searchable?: boolean;
    /** Set to `true` when you have a `multi-select` scenario */
    multiple?: boolean;
    /** Highlights this text in the options list only when the Select is not searchable. */
    highlightedText?: string;
    searchInputValue: string;
    selectAllIsSelected: boolean;
    selectedOptionsWithValuesOnly: (string | number)[];
    listRef: React.Ref<HTMLUListElement>;
    onKeyDown?: (e: React.KeyboardEvent<HTMLLIElement>) => void;
    handleSelect: (option: T) => void;
    handleSelectAll: (selected: boolean) => void;
    optionType?: SelectOptionType;
}>;
export declare type ListBoxOptionProps<T extends SelectOption> = Omit<OptionProps<T>, 'highlightedText' | 'onSelect' | 'selected' | 'optionStyle' | 'optionType'>;
declare type ListboxOption<T extends SelectOption> = React.FC<ListBoxOptionProps<T>>;
declare const ListBox: {
    <T extends SelectOption>({ children, searchable, highlightedText, multiple, searchInputValue, selectAllIsSelected, selectedOptionsWithValuesOnly, listRef, onKeyDown, handleSelect, handleSelectAll, optionType, }: ListBoxProps<T>): JSX.Element;
    displayName: string;
    SelectAllOption: ({ label, ...passedProps }: import("./components/SelectAllOption").SelectAllOptionProps) => JSX.Element;
    OptionGroup: ({ name, children }: import("./components/OptionGroup").OptionGroupProps) => JSX.Element;
    Option: ListboxOption<any>;
};
export default ListBox;
