import React, { PropsWithChildren } from 'react';
import { noop, OutlineVariant } from '@highlight-ui/utils-commons';
import { SelectOption, SelectVariant } from '../types';
export declare type PopoverTriggerProps<T extends SelectOption> = PropsWithChildren<{
    /** Should component be enabled or disabled */
    disabled: boolean;
    /** Label being shown by default on the trigger button */
    label: string;
    /** Id passed to the trigger */
    triggerId?: string;
    /** Sets the color of the input's border */
    outline?: OutlineVariant;
    /** Automatically focus the Select's trigger on mount */
    autoFocus?: boolean;
    /** `inline` when used outside forms and `full-width` when used inside forms. */
    variant: SelectVariant;
    /** passed state for visibility of content */
    visible: boolean;
    /** The callback to execute when interacting with the trigger */
    onClick: typeof noop;
    /** trigger ref to correctly position dropdown */
    selectRef: React.Ref<HTMLElement>;
    /** The callback to clear all selected options */
    onClear?: (evt: React.MouseEvent | React.KeyboardEvent) => void;
    /** The callback to remove 1 option */
    onRemove?: (option: T) => void;
    /** The callback for when the list's visibility changes */
    setListVisibility: (value: boolean) => void;
    /** custom ref passed from popover */
    triggerRef: React.Ref<HTMLElement>;
    /** Set to `true` when you have a `multi-select` scenario */
    multiple?: boolean;
    /** Array of all selected options */
    selectedOptions: T[];
    /** Sets a callback for onKeyDown event when a key is pressed. */
    onKeyDown?: (e: React.KeyboardEvent<HTMLElement>) => void;
}>;
declare const PopoverTrigger: {
    <T extends SelectOption>({ children, triggerRef, ...passedProps }: PopoverTriggerProps<T>): any;
    displayName: string;
};
export default PopoverTrigger;
